<?php

namespace Litecms\BusCategory\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\BusCategory\Models\BusCategory;

class BusCategoryPolicy
{

    /**
     * Determine if the given user can view the bus_category.
     *
     * @param UserPolicy $user
     * @param BusCategory $bus_category
     *
     * @return bool
     */
    public function view(UserPolicy $user, BusCategory $bus_category)
    {
        if ($user->canDo('bus_category.bus_category.view') && $user->isAdmin()) {
            return true;
        }

        return $bus_category->user_id == user_id() && $bus_category->user_type == user_type();
    }

    /**
     * Determine if the given user can create a bus_category.
     *
     * @param UserPolicy $user
     * @param BusCategory $bus_category
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('bus_category.bus_category.create');
    }

    /**
     * Determine if the given user can update the given bus_category.
     *
     * @param UserPolicy $user
     * @param BusCategory $bus_category
     *
     * @return bool
     */
    public function update(UserPolicy $user, BusCategory $bus_category)
    {
        if ($user->canDo('bus_category.bus_category.edit') && $user->isAdmin()) {
            return true;
        }

        return $bus_category->user_id == user_id() && $bus_category->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given bus_category.
     *
     * @param UserPolicy $user
     * @param BusCategory $bus_category
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BusCategory $bus_category)
    {
        return $bus_category->user_id == user_id() && $bus_category->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given bus_category.
     *
     * @param UserPolicy $user
     * @param BusCategory $bus_category
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BusCategory $bus_category)
    {
        if ($user->canDo('bus_category.bus_category.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given bus_category.
     *
     * @param UserPolicy $user
     * @param BusCategory $bus_category
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BusCategory $bus_category)
    {
        if ($user->canDo('bus_category.bus_category.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
